@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.h,v 1.1 2004/03/06 00:15:18 adamh Exp $
+ *  $Id: mozilla-helpers.h,v 1.4 2004/03/15 22:07:05 adamh Exp $
  */
 
 #ifndef POPUP_BLOCKER_MOZILLA_HELPERS_H
@@ -41,6 +41,15 @@ PopupListenerFreeData	*mozilla_register_popup_listener	(EphyEmbed *embed);
 
 void			mozilla_unregister_popup_listener	(PopupListenerFreeData *data);
 
+void			mozilla_enable_javascript		(EphyEmbed *embed,
+								 gboolean enable);
+
+void			mozilla_open_popup			(EphyEmbed *embed,
+								 const char *url,
+								 const char *features);
+
+char *			mozilla_get_location			(EphyEmbed *embed);
+
 G_END_DECLS
 
 #endif /* POPUP_BLOCKER_MOZILLA_HELPERS_H */
